@@ -17,7 +17,7 @@
 
 from warnings import warn
 from pyspark import keyword_only
-from ai.h2o.sparkling.Initializer import Initializer
+from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OTreeBasedUnsupervisedAlgorithm import H2OTreeBasedUnsupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationForestMOJOModel
@@ -33,7 +33,6 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgor
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -44,6 +43,7 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgor
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  sampleSize=256,
                  sampleRate=-1.0,
                  mtries=-1,
