@@ -32,7 +32,6 @@ class H2OAutoMLClassifier(H2OAutoML):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -44,8 +43,9 @@ class H2OAutoMLClassifier(H2OAutoML):
                  splitRatio=1.0,
                  monotoneConstraints={},
                  withStageResults=False,
+                 withDetailedPredictionCol=True,
                  projectName=None,
-                 nfolds=-1,
+                 nfolds=5,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
@@ -53,11 +53,6 @@ class H2OAutoMLClassifier(H2OAutoML):
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
-                 distribution="AUTO",
-                 tweediePower=1.5,
-                 quantileAlpha=0.5,
-                 huberAlpha=0.9,
-                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
