@@ -32,7 +32,6 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
-                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -80,6 +79,7 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
                  quietMode=False,
                  scoreValidationSampling="Uniform",
                  overwriteWithBestModel=True,
+                 autoencoder=False,
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
@@ -134,10 +134,7 @@ class H2ODeepLearningClassifier(H2ODeepLearning):
             if 'calculateFeatureImportances' not in kwargs:
                 kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
             del kwargs['variableImportances']
-            warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.38.")
-        if 'autoencoder' in kwargs:
-            del kwargs['autoencoder']
-            warn("The parameter 'autoencoder' is deprecated and will be removed in the version 3.38.")
+            warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
