@@ -30,6 +30,7 @@ class H2OGAMClassifier(H2OGAM):
                  betaConstraints=None,
                  gamCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -50,6 +51,7 @@ class H2OGAMClassifier(H2OGAM):
                  solver="AUTO",
                  alphaValue=None,
                  lambdaValue=None,
+                 startval=None,
                  lambdaSearch=False,
                  earlyStopping=True,
                  nlambdas=-1,
@@ -77,6 +79,8 @@ class H2OGAMClassifier(H2OGAM):
                  scale=None,
                  bs=None,
                  keepGamCols=False,
+                 standardizeTpGamCols=False,
+                 scaleTpPenaltyMat=False,
                  knotIds=None,
                  modelId=None,
                  nfolds=0,
@@ -95,12 +99,14 @@ class H2OGAMClassifier(H2OGAM):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGAM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OGAMClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
