@@ -30,6 +30,7 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                  initialWeights=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -82,7 +83,7 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
-                 variableImportances=True,
+                 calculateFeatureImportances=True,
                  fastMode=True,
                  forceLoadBalance=True,
                  replicateTrainingData=True,
@@ -121,13 +122,19 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.0,
                  exportCheckpointsDir=None,
-                 aucType="AUTO"):
+                 aucType="AUTO",
+                 **kwargs):
         Initializer.load_sparkling_jar()
         super(H2ODeepLearning, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2ODeepLearningRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-
+        kwargs = self._updateInitKwargs(kwargs)
+        if 'variableImportances' in kwargs:
+            if 'calculateFeatureImportances' not in kwargs:
+                kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
+            del kwargs['variableImportances']
+            warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
