@@ -1,17 +1,15 @@
-from h2o.plot import decorate_plot_result, get_matplotlib_pyplot, RAISE_ON_FIGURE_ACCESS
+from h2o.utils.ext_dependencies import get_matplotlib_pyplot
 from h2o.utils.typechecks import assert_is_type
 
 
 class VariableImportance:
 
-    def _varimp_plot(self, num_of_features=None, server=False, save_plot_path=None):
+    def _varimp_plot(self, num_of_features=None, server=False):
         """
         Plot the variable importance for a trained model.
 
         :param num_of_features: the number of features shown in the plot (default is 10 or all if less than 10).
         :param server: if true set server settings to matplotlib and show the graph
-        :param save_plot_path: a path to save the plot via using matplotlib function savefig
-        :return: object that contains the resulting figure (can be accessed using result.figure())
 
         :returns: None.
         """
@@ -20,7 +18,7 @@ class VariableImportance:
 
         plt = get_matplotlib_pyplot(server)
         if plt is None:
-            return decorate_plot_result(figure=RAISE_ON_FIGURE_ACCESS)
+            return
 
         # get the variable importances as a list of tuples, do not use pandas dataframe
         importances = self.varimp(use_pandas=False)
@@ -72,8 +70,3 @@ class VariableImportance:
         plt.title("Variable Importance: H2O %s" % self._model_json["algo_full_name"], fontsize=20)
         if not server:
             plt.show()
-            
-        if save_plot_path is not None:
-            plt.savefig(fname=save_plot_path)
-
-        return decorate_plot_result(figure=plt.gcf())    
