@@ -32,17 +32,20 @@ import sys
 
 from sklearn.base import ClassifierMixin, RegressorMixin
 
+from h2o.utils.mixin import register_module
 from .. import automl
 from .. import estimators
 from .. import transforms
-from .wrapper import estimator, params_as_h2o_frames, register_module, transformer, H2OConnectionMonitorMixin, \
+from .wrapper import estimator, params_as_h2o_frames, transformer, H2OConnectionMonitorMixin, \
     H2OEstimatorPredictProbabilitiesSupport, H2OEstimatorScoreSupport, H2OEstimatorTransformSupport
 
 module = sys.modules[__name__]
 
+
 def _noop(*args, **kwargs):
     pass
 
+
 def _register_submodule(name=None):
     """
     If name is provided, this registers and attaches a new submodule to the current module.
@@ -57,17 +60,6 @@ def _register_submodule(name=None):
     return mod_name
 
 
-def _make_default_params(cls):
-    """
-    :param cls: the original h2o estimator class.
-    :return: a dictionary representing the default estimator params
-    that will be used to generate the constructor for the sklearn wrapper.
-    """
-    if hasattr(cls, 'param_names'):  # for subclasses of H2OEstimator
-        return {k: None for k in cls.param_names}
-    return None
-
-
 def _get_custom_params(cls):
     """
     :param cls: the original h2o estimator class.
@@ -104,6 +96,7 @@ def _estimator_supports_predict_proba(cls):
     return cls.__name__ not in ['H2OAutoEncoderEstimator',
                                 'H2OGeneralizedLowRankEstimator',
                                 'H2OIsolationForestEstimator',
+                                'H2OExtendedIsolationForestEstimator',
                                 'H2OKMeansEstimator',
                                 'H2OPrincipalComponentAnalysisEstimator',
                                 'H2OSingularValueDecompositionEstimator',
@@ -114,6 +107,7 @@ def _estimator_supports_score(cls):
     return cls.__name__ not in ['H2OAutoEncoderEstimator',
                                 'H2OGeneralizedLowRankEstimator',
                                 'H2OIsolationForestEstimator',
+                                'H2OExtendedIsolationForestEstimator',
                                 'H2OKMeansEstimator',
                                 'H2OPrincipalComponentAnalysisEstimator',
                                 'H2OSingularValueDecompositionEstimator',
@@ -145,7 +139,6 @@ def make_estimator(cls, name=None, submodule=None):
     if name is None:
         name = cls.__name__.replace('Estimator', '') + 'Estimator'
     return estimator(cls, name=name, module=_register_submodule(submodule),
-                     default_params=_make_default_params(cls),
                      mixins=_order_estimator_mixins(cls, type='estimator'),
                      is_generic=True,
                      custom_params=_get_custom_params(cls),
@@ -156,7 +149,6 @@ def make_classifier(cls, name=None, submodule=None):
     if name is None:
         name = cls.__name__.replace('Estimator', '') + 'Classifier'
     return estimator(cls, name=name, module=_register_submodule(submodule),
-                     default_params=_make_default_params(cls),
                      mixins=_order_estimator_mixins(cls, extra=(ClassifierMixin,), type='classifier'),
                      is_generic=False,
                      custom_params=_get_custom_params(cls),
@@ -167,7 +159,6 @@ def make_regressor(cls, name=None, submodule=None):
     if name is None:
         name = cls.__name__.replace('Estimator', '') + 'Regressor'
     return estimator(cls, name=name, module=_register_submodule(submodule),
-                     default_params=_make_default_params(cls),
                      mixins=_order_estimator_mixins(cls, extra=(RegressorMixin,), type='regressor'),
                      is_generic=False,
                      custom_params=_get_custom_params(cls),
@@ -178,7 +169,6 @@ def make_transformer(cls, name=None, submodule=None):
     if name is None:
         name = cls.__name__
     return transformer(cls, name=name, module=_register_submodule(submodule),
-                       default_params=_make_default_params(cls),
                        custom_params=_get_custom_params(cls),
                        )
 
@@ -213,6 +203,7 @@ _generic_only_estimators = (  # e.g. unsupervised and misc estimators
     'H2OGeneralizedLowRankEstimator',
     'H2OGenericEstimator',
     'H2OIsolationForestEstimator',
+    'H2OExtendedIsolationForestEstimator',
     'H2OKMeansEstimator',
     'H2OPrincipalComponentAnalysisEstimator',
     'H2OSingularValueDecompositionEstimator',
